@@ -7,7 +7,7 @@
  *  within the code that implements the API.
  */
 
-// Copyright (C) 2014-2020 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef DDCUTIL_TYPES_H_
@@ -134,28 +134,29 @@ typedef enum {
 //!
 //! Used as bitflags to specify multiple trace types
 typedef enum {
- DDCA_TRC_BASE  = 0x0080,       /**< base functions          */
- DDCA_TRC_I2C   = 0x0040,       /**< I2C layer               */
- DDCA_TRC_ADL   = 0x0020,       /**< ADL layer               */
- DDCA_TRC_DDC   = 0x0010,       /**< DDC layer               */
- DDCA_TRC_USB   = 0x0008,       /**< USB connected display functions */
- DDCA_TRC_TOP   = 0x0004,       /**< ddcutil mainline        */
- DDCA_TRC_ENV   = 0x0002,       /**< environment command     */
- DDCA_TRC_API   = 0x0001,       /**< top level API functions */
- DDCA_TRC_UDF   = 0x0100,       /**< user-defined, aka dynamic, features */
- DDCA_TRC_VCP   = 0x0200,       /**< VCP layer, feature definitions */
- DDCA_TRC_DDCIO = 0x0400,       /**< DDC IO functions */
- DDCA_TRC_SLEEP = 0x0800,       /**< low level sleeps */
- DDCA_TRC_RETRY = 0x1000,       /**< successful retries, subset of DDCA_TRC_SLEEP */
+   DDCA_TRC_BASE  = 0x0080,       /**< base functions          */
+   DDCA_TRC_I2C   = 0x0040,       /**< I2C layer               */
+   DDCA_TRC_ADL   = 0x0020,       /**< ADL layer               */
+   DDCA_TRC_DDC   = 0x0010,       /**< DDC layer               */
+   DDCA_TRC_USB   = 0x0008,       /**< USB connected display functions */
+   DDCA_TRC_TOP   = 0x0004,       /**< ddcutil mainline        */
+   DDCA_TRC_ENV   = 0x0002,       /**< environment command     */
+   DDCA_TRC_API   = 0x0001,       /**< top level API functions */
+   DDCA_TRC_UDF   = 0x0100,       /**< user-defined, aka dynamic, features */
+   DDCA_TRC_VCP   = 0x0200,       /**< VCP layer, feature definitions */
+   DDCA_TRC_DDCIO = 0x0400,       /**< DDC IO functions */
+   DDCA_TRC_SLEEP = 0x0800,       /**< low level sleeps */
+   DDCA_TRC_RETRY = 0x1000,       /**< successful retries, subset of DDCA_TRC_DDCIO */
 
- DDCA_TRC_NONE = 0x0000,        /**< all tracing disabled    */
- DDCA_TRC_ALL  = 0xffff         /**< all tracing enabled     */
+   DDCA_TRC_NONE  = 0x0000,       /**< all tracing disabled    */
+   DDCA_TRC_ALL   = 0xffff        /**< all tracing enabled     */
 } DDCA_Trace_Group;
 
 
 typedef enum {
    DDCA_TRCOPT_TIMESTAMP = 0x01,
    DDCA_TRCOPT_THREAD_ID = 0x02,
+   DDCA_TRCOPT_WALLTIME  = 0x04
 } DDCA_Trace_Options;
 
 
@@ -346,7 +347,10 @@ typedef struct {
 
 
 #define DDCA_DISPLAY_INFO_MARKER "DDIN"
-/** Describes one monitor detected by ddcutil. */
+/** Describes one monitor detected by ddcutil.
+ *
+ *  This struct is copied to the caller and can simply be freed.
+ */
 typedef struct {
    char                   marker[4];        ///< always "DDIN"
    int                    dispno;           ///< ddcutil assigned display number
@@ -460,7 +464,7 @@ struct {
    DDCA_MCCS_Version_Spec                vcp_version;    /**< MCCS version    */
    DDCA_Feature_Flags                    feature_flags;  /**< feature type description */
    DDCA_Feature_Value_Entry *            sl_values;      /**< valid when DDCA_SIMPLE_NC set */
-   DDCA_Feature_Value_Entry *            latest_sl_values;
+   DDCA_Feature_Value_Entry *            latest_sl_values;  /** no longer used */
    char *                                feature_name;   /**< feature name */
    char *                                feature_desc;   /**< feature description */
    // possibly add pointers to formatting functions
